@@ -11,7 +11,7 @@
 #' @param hypothesis Character string. The hypothesis (or hypotheses) to be tested. See details.
 #'
 #' @param prior_sd Numeric. Scale of the prior distribution, approximately the standard deviation
-#'                 of a beta distribution (defaults to sqrt(1/12)).
+#'                 of a beta distribution (defaults to 0.5).
 #'
 #' @param formula An object of class \code{\link[stats]{formula}}. This allows for including
 #' control variables in the model (e.g.,, \code{~ gender * education}).
@@ -213,7 +213,7 @@
 #' }
 #'@export
 confirm <- function(Y, hypothesis,
-                    prior_sd = sqrt(1/12),
+                    prior_sd = 0.5,
                     formula = NULL,
                     type = "continuous",
                     mixed_type = NULL,
